window.Gleam.initSearch([{"doc":"shamir","title":"shamir","content":"# shamir\n\n[![Package Version](https://img.shields.io/hexpm/v/shamir)](https://hex.pm/packages/shamir)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/shamir/)\n\n```sh\ngleam add shamir\n```\n```gleam\nimport shamir\n\npub fn main() {\n  let secret = &quot;testing123!&quot;\n  io.println(&quot;Original: &quot; &lt;&gt; data)\n  let share_res = shamir.share(data, 5, 3)\n  let assert Ok([share_1, share_2, share_3, share_4, share_5]) = share_res\n  io.println(&quot;Share 1: &quot; &lt;&gt; share_1)\n  io.println(&quot;Share 2: &quot; &lt;&gt; share_2)\n  io.println(&quot;Share 3: &quot; &lt;&gt; share_3)\n  io.println(&quot;Share 4: &quot; &lt;&gt; share_4)\n  io.println(&quot;Share 5: &quot; &lt;&gt; share_5)\n  let assert Ok(combined) = shamir.combine([share_1, share_3, share_5])\n  io.println(&quot;Combined Shares: &quot; &lt;&gt; combined)\n  let assert Ok(share_new) = shamir.new_share(6, [share_1, share_3, share_4])\n  io.println(&quot;New Share: &quot; &lt;&gt; share_new)\n  let assert Ok(new_combined) = shamir.combine([share_1, share_4, share_new])\n  io.println(&quot;Combined New Shares: &quot; &lt;&gt; new_combined)\n}\n```\n\nFurther documentation can be found at &lt;https://hexdocs.pm/shamir&gt;.\n\n## Development\n\n```sh\ngleam run   # Run the project\ngleam test  # Run the tests\ngleam shell # Run an Erlang shell\n```\n","url":"index.html"},{"doc":"shamir","title":"ShamirError","content":"pub type ShamirError {\n  NotEnoughShares\n  MalformedId\n  IdOutOfRange\n  DuplicateIds\n  MalformedData\n  MissingLookupValue\n  InvalidStringValue\n  InvalidShareNumber\n  InvalidThreshold\n  NotEnoughSharesForThreshold\n  InvalidPadLength\n}\n\nNotEnoughShares\n\n\nMalformedId\n\n\nIdOutOfRange\n\n\nDuplicateIds\n\n\nMalformedData\n\n\nMissingLookupValue\n\n\nInvalidStringValue\n\n\nInvalidShareNumber\n\n\nInvalidThreshold\n\n\nNotEnoughSharesForThreshold\n\n\nInvalidPadLength\n\n\nSynonyms:\nshamir.ShamirError\nshamir ShamirError","url":"shamir.html#ShamirError"},{"doc":"shamir","title":"combine","content":"pub fn combine(\n  shares: List(String),\n) -&gt; Result(String, ShamirError)\n\nSynonyms:\nshamir.combine\nshamir combine","url":"shamir.html#combine"},{"doc":"shamir","title":"new_share","content":"pub fn new_share(\n  id: Int,\n  shares: List(String),\n) -&gt; Result(String, ShamirError)\n\nSynonyms:\nshamir.new_share\nshamir new_share","url":"shamir.html#new_share"},{"doc":"shamir","title":"share","content":"pub fn share(\n  secret: String,\n  num_shares: Int,\n  threshold: Int,\n) -&gt; Result(List(String), ShamirError)\n\nSynonyms:\nshamir.share\nshamir share","url":"shamir.html#share"},{"doc":"shamir","title":"share_with_pad_length","content":"pub fn share_with_pad_length(\n  secret: String,\n  num_shares: Int,\n  threshold: Int,\n  pad_length: Int,\n) -&gt; Result(List(String), ShamirError)\n\nSynonyms:\nshamir.share_with_pad_length\nshamir share_with_pad_length","url":"shamir.html#share_with_pad_length"},{"doc":"shamir","title":"shamir","content":"","url":"shamir.html"}]);